@@ -6,15 +6,16 @@ from textwrap import dedent
 from typing import TYPE_CHECKING
 
 import pytest
+from dirty_equals import IsStr
 from jinja2.exceptions import TemplateNotFound
 from markdown import Markdown
 
-from mkdocstrings.handlers.base import Highlighter
+from mkdocstrings import Highlighter
 
 if TYPE_CHECKING:
     from pathlib import Path
 
-    from mkdocstrings.plugin import MkdocstringsPlugin
+    from mkdocstrings import MkdocstringsPlugin
 
 
 @pytest.mark.parametrize("extension_name", ["codehilite", "pymdownx.highlight"])
@@ -120,14 +121,14 @@ def test_nested_autodoc(ext_markdown: Markdown) -> None:
         {
             "level": 1,
             "id": "tests.fixtures.nesting.Class",
-            "html": "",
+            "html": IsStr(),
             "name": "Class",
             "data-toc-label": "Class",
             "children": [
                 {
                     "level": 2,
                     "id": "tests.fixtures.nesting.Class.method",
-                    "html": "",
+                    "html": IsStr(),
                     "name": "method",
                     "data-toc-label": "method",
                     "children": [],
